unit SettingsFrame;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, JSEditDialogIntf, JSEditDialog, StdCtrls, CheckLst, ExtCtrls;

type
  TfrSettings = class(TFrame, IJSEditDialogControl)
    rbSettingOne: TRadioButton;
    rbSettingTwo: TRadioButton;
    eSettingOne: TEdit;
    cboxListItems: TComboBox;
    Bevel1: TBevel;
    Label1: TLabel;
    Label2: TLabel;
    clbAdditionalOptions: TCheckListBox;
    procedure rbSettingOneClick(Sender: TObject);
    procedure eSettingOneChange(Sender: TObject);
    procedure clbAdditionalOptionsClickCheck(Sender: TObject);
  private
    FJSDialog: TJSCustomEditDialog;
    FActiveControlInError: TWinControl;
    procedure CheckValidation;
  public
    function ActiveControl: TWinControl;
    function ActiveControlInError: TWinControl;
    procedure AdjustControlLayout(const AWidth: Integer);
    function GetRequiredWidth: Integer;
    procedure SetActiveControlInError(AControl: TWinControl);
    procedure SetDialog(JSDialog: TJSCustomEditDialog);
    function ValidateInput(out Message: string;
      const ModalResult: TModalResult): Boolean;
  end;

implementation

{$R *.dfm}

uses
  JSDialog;

{ TfrSettings }

function TfrSettings.ActiveControl: TWinControl;
begin
  Result := rbSettingOne;
end;

function TfrSettings.ActiveControlInError: TWinControl;
begin
  Result := FActiveControlInError;
end;

procedure TfrSettings.AdjustControlLayout(const AWidth: Integer);
begin
  // No implementation needed
end;

procedure TfrSettings.eSettingOneChange(Sender: TObject);
begin
  CheckValidation;
end;

function TfrSettings.GetRequiredWidth: Integer;
begin
  Result := 308;
end;

procedure TfrSettings.rbSettingOneClick(Sender: TObject);
begin
  CheckValidation;
end;

procedure TfrSettings.SetActiveControlInError(AControl: TWinControl);
begin
  FActiveControlInError := AControl;
end;

procedure TfrSettings.SetDialog(JSDialog: TJSCustomEditDialog);
begin
  FJSDialog := JSDialog;
end;

function TfrSettings.ValidateInput(out Message: string;
  const ModalResult: TModalResult): Boolean;
var
  I: Integer;
  LChecked: Integer;
  LError: string;
begin
  Result := True;
  if ModalResult = mrOK then
  begin
    if rbSettingOne.Checked then
    begin
      if eSettingOne.Text = '' then
      begin
        Result := False;
        Message := 'You must enter a value for Setting One.';
        SetActiveControlInError(eSettingOne);
      end
      else if eSettingOne.Text[1] <> 'A' then
      begin
        Result := False;
        Message := 'The value for setting one must start with "A".';
        SetActiveControlInError(eSettingOne);
      end
    end;
    LChecked := 0;
    for I := 0 to clbAdditionalOptions.Items.Count - 1 do
    begin
      if clbAdditionalOptions.Checked[I] then
        Inc(LChecked);
    end;
    if (LChecked < 2) then
    begin
      LError := 'You must check at least two items in the additional options list.';
      if Result then
      begin
        SetActiveControlInError(clbAdditionalOptions);
        Message := LError;
        Result := False;
      end
      else
        Message := Message + #13#10 + LError;
    end;
  end;
end;

procedure TfrSettings.CheckValidation;
var
  LDialogValid: Boolean;
  LMessage: string;
begin
  LDialogValid := ValidateInput(LMessage, mrOK);
  // Since we are silently validating the dialog, we won't display the
  // validation messages to the user.
  FJSDialog.EnableButton(BASE_CUSTOMBUTTON, LDialogValid);
end;

procedure TfrSettings.clbAdditionalOptionsClickCheck(Sender: TObject);
begin
  CheckValidation;
end;

end.
